#ifndef __RESOURCE_thunar_H__
#define __RESOURCE_thunar_H__

#include <gio/gio.h>

extern GResource *thunar_get_resource (void);
#endif
